abacusai.api_class.feature_group — AbacusAI documentation

# `abacusai.api_class.feature_group`

## Module Contents

### Classes

`SamplingConfig` | An abstract class for the sampling config of a feature group
`NSamplingConfig` | The number of distinct values of the key columns to include in the sample, or number of rows if key columns not specified.
`PercentSamplingConfig` | The fraction of distinct values of the feature group to include in the sample.
`_SamplingConfigFactory` | Helper class that provides a standard way to create an ABC using
`MergeConfig` | An abstract class for the merge config of a feature group
`LastNMergeConfig` | Merge LAST N chunks/versions of an incremental dataset.
`TimeWindowMergeConfig` | Merge rows within a given timewindow of the most recent timestamp
`_MergeConfigFactory` | Helper class that provides a standard way to create an ABC using

class abacusai.api_class.feature_group.SamplingConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  An abstract class for the sampling config of a feature group

  __post_init__()

class abacusai.api_class.feature_group.NSamplingConfig

  Bases: `SamplingConfig`

  The number of distinct values of the key columns to include in the sample, or number of rows if key columns not specified.

  Parameters:

    - sampling_method (SamplingMethodType) – N_SAMPLING

    - sample_count (int) – The number of rows to include in the sample

    - key_columns (List[str]) – The feature(s) to use as the key(s) when sampling

  sample_count: int
  key_columns: List[str]
  sampling_method: abacusai.api_class.enums.SamplingMethodType

class abacusai.api_class.feature_group.PercentSamplingConfig

  Bases: `SamplingConfig`

  The fraction of distinct values of the feature group to include in the sample.

  Parameters:

    - sampling_method (SamplingMethodType) – PERCENT_SAMPLING

    - sample_percent (float) – The percentage of the rows to sample

    - key_columns (List[str]) – The feature(s) to use as the key(s) when sampling

  sample_percent: float
  key_columns: List[str]
  sampling_method: abacusai.api_class.enums.SamplingMethodType

class abacusai.api_class.feature_group._SamplingConfigFactory

  Bases: `abacusai.api_class.abstract._ApiClassFactory`

  Helper class that provides a standard way to create an ABC using inheritance.

  config_class_key = 'sampling_method'
  config_class_map

class abacusai.api_class.feature_group.MergeConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  An abstract class for the merge config of a feature group

  __post_init__()

class abacusai.api_class.feature_group.LastNMergeConfig

  Bases: `MergeConfig`

  Merge LAST N chunks/versions of an incremental dataset.

  Parameters:

    - merge_mode (MergeMode) – LAST_N

    - num_versions (int) – The number of versions to merge. num_versions == 0 means merge all versions.

  num_versions: int
  merge_mode: abacusai.api_class.enums.MergeMode

class abacusai.api_class.feature_group.TimeWindowMergeConfig

  Bases: `MergeConfig`

  Merge rows within a given timewindow of the most recent timestamp

  Parameters:

    - merge_mode (MergeMode) – TIME_WINDOW

    - feature_name (str) – Time based column to index on

    - time_window_size_ms (int) – Range of merged rows will be [MAX_TIME - time_window_size_ms, MAX_TIME]

  feature_name: str
  time_window_size_ms: int
  merge_mode: abacusai.api_class.enums.MergeMode

class abacusai.api_class.feature_group._MergeConfigFactory

  Bases: `abacusai.api_class.abstract._ApiClassFactory`

  Helper class that provides a standard way to create an ABC using inheritance.

  config_class_key = 'merge_mode'
  config_class_map